import React from "react";
import styled from "styled-components";

import { ButtonProps } from "../../..";
import {
  white,
  redpink50,
  ic_common_phone_20_white,
  ic_common_phone_20_red,
} from "../../common";

export const Button: React.FunctionComponent<ButtonProps> = (props) => {
  return <StyledButton {...props} />;
};

const StyledButton = styled.button<ButtonProps>`
  ${({ size, variant, tel, dot }) => {
    let color = white;
    let background = redpink50;
    let telImg = ic_common_phone_20_white;

    let fontSize = "15px";
    let height = "44px";

    switch (variant) {
      case "white": {
        color = redpink50;
        background = white;
        telImg = ic_common_phone_20_red;
        break;
      }
    }

    switch (size) {
      case "large": {
        fontSize = "16px";
        height = "50px";
        break;
      }
    }

    return `
        position: relative;
        display: inline-flex;
        align-items: center;
        justify-content: center;
        line-height: 0;
        cursor: pointer;

        height: ${height};
        max-height: ${height};
        padding: 0 24px;
        border-radius: 6px;
        font-size: ${fontSize};
        font-weight: bold;

        border: 1px solid ${redpink50};

        color: ${color};
        background: ${background};

        ${
          tel
            ? `
            padding-left: 20px;
            
            &:before {
                content: "";
                display: inline-block;
                margin-right: 4px;
                width: 20px;
                height: 20px;
                background: ${telImg};
            }
        `
            : ``
        }
        ${
          dot
            ? `
            &:after {
                position: absolute;
                right: 17px;
                top: 10px;
                content: "";
                display: inline-block;
                width: 4px;
                height: 4px;
                border-radius: 100%;
                background: ${color};
            }
        `
            : ``
        }
      `;
  }}
`;

export const MobileButton = styled(StyledButton)`
  width: 100%;
`;
