import React from "react";
import styled from "styled-components";

import { NavTabProps } from "../../..";
import { darkgray50, redpink50, white } from "../../common";

export const NavTab: React.FunctionComponent<NavTabProps> = (props) => {
  const { title, active, children, onMouseEnter, onMouseLeave, variant } =
    props;
  return (
    <Tab
      active={active}
      variant={variant}
      onMouseEnter={onMouseEnter}
      onMouseLeave={onMouseLeave}
    >
      {title}
      {children}
    </Tab>
  );
};

const Tab = styled.button<{ active?: boolean; variant?: "black" | "white" }>`
  ${({ active, variant }) => {
    let color = darkgray50;

    const borderColor = active ? redpink50 : "transparent";

    switch (variant) {
      case "black": {
        color = darkgray50;
        break;
      }
      case "white": {
        color = white;
        break;
      }
    }

    return `
        padding: 2px;
        height: 30px;
        max-height: 31px;
        background: none;
        border: none;
        border-bottom: 2px solid ${borderColor};
        color: ${color};

        font-size: 15px;
        font-weight: bold;
    `;
  }}
`;
