import React from "react";
import styled from "styled-components";
import { TitleProps } from "../../..";
import {
  mobile,
  redpink50,
  brown50,
  tablet,
  underline_red,
  underline_yellow,
} from "../../common";

export const Title: React.FunctionComponent<TitleProps> = (props) => {
  const { text, caption, exclusive } = props;
  return (
    <Container>
      {caption && <Caption exclusive={exclusive}>{caption}</Caption>}
      <div>
        {text.map((t, index) => {
          return (
            <Text key={index} highlight={index === 1} exclusive={exclusive}>
              {t}
            </Text>
          );
        })}
      </div>
    </Container>
  );
};

const Caption = styled.span<{ exclusive?: boolean }>`
  display: inline-block;
  font-size: 16px;
  font-weight: bold;
  letter-spacing: -0.5px;
  color: ${(props) => (props.exclusive ? brown50 : redpink50)};
  margin-bottom: 16px;
`;

const Container = styled.div``;

const Text = styled.span<{ highlight: boolean; exclusive?: boolean }>`
  word-break: keep-all;
  font-size: 44px;
  font-weight: bold;
  line-height: 1.36;
  letter-spacing: -1px;

  @media (max-width: ${tablet}) {
    font-size: 38px;
    line-height: 1.37;
    letter-spacing: -0.5px;
  }

  @media (max-width: ${mobile}) {
    font-size: 32px;
    line-height: 1.38;
  }

  ${(props) =>
    props.highlight
      ? `
        background: ${props.exclusive ? underline_yellow : underline_red};
        background-position: 0 1.04em;
        background-repeat: repeat-x;
        background-size: 1px 14px;
        @media (max-width: ${tablet}) {
            background-size: 1px 10px;
        }
        `
      : ""}
`;
